@@ -10,8 +10,10 @@ test_that ("bbox", {
         bbox_to_string (1:5),
         "only the first four elements of bbox used"
     )
-    expect_error (bbox_to_string (data.frame(a="type", b="id")),
-                  "bbox must be a data.frame with osm_type and osm_id columns")
+    expect_error (
+        bbox_to_string (data.frame (a = "type", b = "id")),
+        "bbox must be a data.frame with osm_type and osm_id columns"
+    )
 })
 
 test_that ("getbb-place_name", {
@@ -34,7 +36,7 @@ test_that ("getbb-place_name", {
     )
     range0 <- apply (res0, 1, function (i) diff (range (i)))
     range2 <- apply (res2, 1, function (i) diff (range (i)))
-    expect_true (all (range2 > range0))
+    expect_true (all (range2 >= range0))
 
     expect_output (
         res0 <- with_mock_dir ("mock_bb", {
@@ -62,9 +64,14 @@ test_that ("getbb-place_name", {
         })
     )
     expect_is (res6, "character")
-    expect_length (res6,  1L)
+    expect_length (res6, 1L)
 
-    expect_error (getbb ("Salzzburg"), "`place_name` 'Salzzburg' can't be found")
+    expect_error (
+        with_mock_dir ("mock_bb_typo", {
+            getbb ("Salzzburg")
+        }),
+        "`place_name` 'Salzzburg' can't be found"
+    )
 })
 
 # Note that the polygon calls produce large mock files which are reduced with
@@ -144,8 +151,10 @@ test_that ("bbox-to-string", {
     area <- data.frame (osm_type = "relation", osm_id = "11747082")
     expect_is (bbox_to_string (area), "character")
     expect_length (bbox_to_string (area), 1)
-    area <- data.frame (osm_type = c ("relation", "relation", "way"),
-                        osm_id = c("11747082", "307833", "22422490"))
+    area <- data.frame (
+        osm_type = c ("relation", "relation", "way"),
+        osm_id = c ("11747082", "307833", "22422490")
+    )
     expect_is (bbox_to_string (area), "character")
     expect_length (bbox_to_string (area), 1)
 })
